// Rechtecksignale mit interruptbasierter Programmierung eines Timers
#include "stm32g0xx_hal.h"
extern TIM_HandleTypeDef htim2;

// Array mit CCR-Werten
volatile uint32_t ccr1Sequence[4]= {799,999,199,499};

// ISR: Compare-Callback-Funktion programmiert neuen CCR-Wert
void HAL_TIM_OC_DelayElapsedCallback (TIM_HandleTypeDef *htim)
{
    static uint8_t cntCCR1 = 1; // Zähler zur Auswahl der Werte
    if (htim == &htim2) {
        if (htim->Channel == HAL_TIM_ACTIVE_CHANNEL_1) {
            // Falls richtiger Timer und Kanal: CCR-Wert neu setzen
            __HAL_TIM_SET_COMPARE(htim,TIM_CHANNEL_1,
                                  ccr1Sequence[cntCCR1]);
            // CCR-Index erhöhen, max. bis 3 laufen lassen
            cntCCR1 = (cntCCR1+1)%4;

            // Statt des Modulo-Operators % könnte man in diesem Fall
            // auch eine UND-Verknüpfung mit dem Wert 4-1 = 3 nutzen.
            // Also: cntCCR1 = (cntCCR1+1)&3;
            // Dies wäre schneller.
            // Aber: Das funktioniert nur für 2er-Potenzen
        }
    }
}

void app() // wird in main() aufgerufen
{
    // 1. CCR-Wert vor dem Start des Timers eintragen
    __HAL_TIM_SET_COMPARE(&htim2,TIM_CHANNEL_1,ccr1Sequence[0]);

    // Timer starten
    HAL_TIM_OC_Start_IT (&htim2,TIM_CHANNEL_1);
    while (1);
}
