// Initialisierung des USART2 mit:
// 8 Datenbits, keine Parität, 1 Stoppbit, keine FIFOs
void USART2_Init (uint32_t baudrate)
{
    // Taktsignale für GPIOA und USART2 aktivieren
    RCC->IOPENR  |= RCC_IOPENR_GPIOAEN;
    RCC->APBENR1 |= RCC_APBENR1_USART2EN;

    // PA2 und PA3 auf "Alternate Function" umschalten
    GPIOA->MODER &= ~GPIO_MODER_MODE2;
    GPIOA->MODER |=  GPIO_MODER_MODE2_1;
    GPIOA->MODER &= ~GPIO_MODER_MODE3;
    GPIOA->MODER |=  GPIO_MODER_MODE3_1;

    // Auswahl der "Alternate Function"
    // Tabellen hierzu befinden sich im Datasheet, z.B. für GPIOA: Table 13
    GPIOA->AFR[0] &= ~GPIO_AFRL_AFSEL2;
    GPIOA->AFR[0] |=  1<<GPIO_AFRL_AFSEL2_Pos;
    GPIOA->AFR[0] &= ~GPIO_AFRL_AFSEL3;
    GPIOA->AFR[0] |=  1<<GPIO_AFRL_AFSEL3_Pos;

    // USART2 konfigurieren
    USART2->CR1 = USART_CR1_TE | USART_CR1_RE | USART_CR1_UE;
    USART2->BRR = SystemCoreClock/baudrate;
}
// Ein Zeichen mit USART empfangen
uint8_t USART_Receive(USART_TypeDef *USART)
{
    // Der Empfang ist nach Fehlern gesperrt
    // Daher: Eventuelle Empfangsfehlerzustände löschen
    USART->ICR = 0xF;
    // auf Daten warten und dann empfangenes Zeichen zurückgeben
    while(!(USART->ISR & USART_ISR_RXNE_RXFNE));
    return USART->RDR;
}

// Ein Zeichen mit USART senden
uint8_t USART_Transmit(USART_TypeDef *USART, uint8_t data)
{
    // warten bis mindestens ein Zeichen in die USART-Hardware
    // geschrieben werden darf
    while(!(USART->ISR & USART_ISR_TXE_TXFNF));
    USART->TDR=data;    // nächstes Zeichen ausgeben
    return 1;   // Anzahl gesendeter Zeichen zurückgeben, hier immer 1
}
